==> xdvik-22.74.3.tar.gz: xdvik-22.74.3/texk/xdvik/xdvi-debug.h <==
#ifndef XDVI_DEBUG_H
#define XDVI_DEBUG_H

/*
 * Copyright (c) 2002 xdvik project
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

/* debugging flags and macros */

#if HAVE_STRINGIZE
#ifdef NDEBUG
/* for production code, a failed ASSERT(x) just prints out a warning;
   else it aborts and dumps core. Since stringification (#x) is an ANSI
   feature, I hope we need no configure test for it ...?
*/
#define ASSERT(x) do {								\
    if(!(x)) {									\
	fprintf(stderr,								\
		"************************************************************\n"\
		"Failed assertion:\n%s:%d: \"%s\"\n"				\
		"Please report this as a bug to:\n"				\
		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"	\
 		"************************************************************\n",\
		__FILE__, __LINE__, #x);					\
    } } while (0)
#else /* NDEBUG */
#define ASSERT(x) do {							        \
    if(!(x)) {									\
	fprintf(stderr,								\
		"\n************************************************************\n"\
		"Failed assertion:\n%s:%d: \"%s\"\n"				\
		"Aborting now. Please report this as a bug to:\n"		\
		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"	\
		"If a core dump has been produced, plese invoke:\n"		\
		"gdb xdvi.bin core\nThen type \"bt\", "			\
		"and include the resulting output in your bug report.\n"	\
 		"************************************************************\n",\
		__FILE__, __LINE__, #x);					\
	do_abort();								\
    } } while (0)
#endif /* NDEBUG */
#else /* HAVE_STRINGIZE */
#define ASSERT(x) /* as nothing */
#endif

extern unsigned long debug;

/* for temporary debugging statements */
#ifdef MYDEBUG
# define MYTRACE(X)   do {                          \
    fprintf(stderr, "%s:%d: ", __FILE__, __LINE__); \
    fprintf X;                                      \
    fprintf(stderr, "\n");                          \
} while(0)
#else
# define MYTRACE(X)
#endif

/* NOTE: keep these in sync with the debug_string_options array in util.c! */
#define	DBG_BITMAP		1
#define	DBG_DVI			2
#define	DBG_PK			4
#define	DBG_BATCH		8
#define	DBG_EVENT		16
#define	DBG_PS			32
/* start of kpathsea debugging options */
#define	DBG_STAT		64
#define	DBG_HASH		128
#define	DBG_OPEN		256
#define	DBG_PATHS		512
#define	DBG_EXPAND		1024
#define	DBG_SEARCH		2048
#define	DBG_KPATHSEA		4032	/* handy abbrev */
/* end of kpathsea debugging options */
#define	DBG_HTEX		4096
#define DBG_SRC_SPECIALS	8192
#define DBG_CLIENT		16384
#define DBG_T1			32768
#define DBG_T1_VERBOSE		65536
#define DBG_GUI			131072
#define	DBG_ALL			(~DBG_BATCH)

/* a mapping of numerical options to descriptive strings, defined in util.c */
typedef struct debug_string_options_t_ {
    int bitmap;
    const char *description;
    const char *help_formatting;
} debug_string_options_t;


#if SPEED_IS_EVERYTHING
/* we don't want this defined for NDEBUG, since the tracing macros
   are pretty useful also for users reporting bugs etc.; so we practically
   always enable them.
*/
#define TRACE_HTEX(X)
#define TRACE_SRC(X)
#define TRACE_CLIENT(X)
#define TRACE_T1(X)
#define TRACE_T1_VERBOSE(X)
#define TRACE_GUI(X)
#else /* SPEED_IS_EVERYTHING */
#define TRACE_HTEX(X)						    \
    do {							    \
	if (debug & DBG_HTEX) {					    \
	    fprintf(stderr, "%s:%d: HTEX: ", __FILE__, __LINE__);   \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_SRC(X)						    \
    do {							    \
	if (debug & DBG_SRC_SPECIALS) {				    \
	    fprintf(stderr, "%s:%d: SRC: ", __FILE__, __LINE__);    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_CLIENT(X)						    \
    do {							    \
	if (debug & DBG_CLIENT) {				    \
	    fprintf(stderr, "%s:%d: CLIENT: ", __FILE__, __LINE__); \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_T1(X)						    \
    do {							    \
	if (debug & DBG_T1) {					    \
	    fprintf(stderr, "%s:%d: T1: ", __FILE__, __LINE__);	    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_T1_VERBOSE(X)					    \
    do {							    \
	if (debug & DBG_T1_VERBOSE) {				    \
	    fprintf(stderr, "%s:%d: T1_VERBOSE: ", __FILE__, __LINE__);	    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_GUI(X)						    \
    do {							    \
	if (debug & DBG_GUI) {					    \
	    fprintf(stderr, "%s:%d: GUI: ", __FILE__, __LINE__);    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#endif /* SPEED_IS_EVERYTHING */

#endif /* XDVI_DEBUG_H */

==> xdvik-22.76.1.tar.gz: xdvik-22.76.1/texk/xdvik/xdvi-debug.h <==
#ifndef XDVI_DEBUG_H
#define XDVI_DEBUG_H

/*
 * Copyright (c) 2002 xdvik project
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

/* debugging flags and macros */

#if HAVE_STRINGIZE
#ifdef NDEBUG
/* for production code, a failed ASSERT(x) just prints out a warning;
   else it aborts and dumps core. Since stringification (#x) is an ANSI
   feature, I hope we need no configure test for it ...?
*/
#define ASSERT(x, y) do {								\
    if(!(x)) {										\
	fprintf(stderr,									\
		"************************************************************\n"	\
		"Failed assertion:\n%s:%d: \"%s\": %s\n"				\
		"Please report this as a bug to:\n"					\
		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"		\
 		"************************************************************\n",	\
		__FILE__, __LINE__, #x, y);						\
    } } while (0)
#else /* NDEBUG */
#define ASSERT(x, y) do {								\
    if(!(x)) {										\
	fprintf(stderr,									\
		"\n************************************************************\n"	\
		"Failed assertion:\n%s:%d: \"%s\": %s\n"				\
		"Aborting now. Please report this as a bug to:\n"			\
		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"		\
		"If a core dump has been produced, plese invoke:\n"			\
		"gdb xdvi.bin core\nThen type \"bt\", "					\
		"and include the resulting output in your bug report.\n"		\
 		"************************************************************\n",	\
		__FILE__, __LINE__, #x, y);						\
	do_abort();									\
    } } while (0)
#endif /* NDEBUG */
#else /* HAVE_STRINGIZE */
#define ASSERT(x, y) /* as nothing */
#endif

extern unsigned long debug;

/* for temporary debugging statements */
#ifdef MYDEBUG
# define MYTRACE(X)   do {                          \
    fprintf(stderr, "%s:%d: ", __FILE__, __LINE__); \
    fprintf X;                                      \
    fprintf(stderr, "\n");                          \
} while(0)
#else
# define MYTRACE(X)
#endif

/* NOTE: keep these in sync with the debug_string_options array in util.c! */
#define	DBG_BITMAP		1
#define	DBG_DVI			2
#define	DBG_PK			4
#define	DBG_BATCH		8
#define	DBG_EVENT		16
#define	DBG_PS			32
/* start of kpathsea debugging options */
#define	DBG_STAT		64
#define	DBG_HASH		128
#define	DBG_OPEN		256
#define	DBG_PATHS		512
#define	DBG_EXPAND		1024
#define	DBG_SEARCH		2048
#define	DBG_KPATHSEA		4032	/* handy abbrev */
/* end of kpathsea debugging options */
#define	DBG_HTEX		4096
#define DBG_SRC_SPECIALS	8192
#define DBG_CLIENT		16384
#define DBG_T1			32768
#define DBG_T1_VERBOSE		65536
#define DBG_GUI			131072
#define	DBG_ALL			(~DBG_BATCH)

/* a mapping of numerical options to descriptive strings, defined in util.c */
typedef struct debug_string_options_t_ {
    int bitmap;
    const char *description;
    const char *help_formatting;
} debug_string_options_t;


#if SPEED_IS_EVERYTHING
/* we don't want this defined for NDEBUG, since the tracing macros
   are pretty useful also for users reporting bugs etc.; so we practically
   always enable them.
*/
#define TRACE_HTEX(X)
#define TRACE_SRC(X)
#define TRACE_CLIENT(X)
#define TRACE_T1(X)
#define TRACE_T1_VERBOSE(X)
#define TRACE_GUI(X)
#define TRACE_EVENTS(X)
#else /* SPEED_IS_EVERYTHING */
#define TRACE_HTEX(X)						    \
    do {							    \
	if (debug & DBG_HTEX) {					    \
	    fprintf(stderr, "%s:%d: HTEX: ", __FILE__, __LINE__);   \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_SRC(X)						    \
    do {							    \
	if (debug & DBG_SRC_SPECIALS) {				    \
	    fprintf(stderr, "%s:%d: SRC: ", __FILE__, __LINE__);    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_CLIENT(X)						    \
    do {							    \
	if (debug & DBG_CLIENT) {				    \
	    fprintf(stderr, "%s:%d: CLIENT: ", __FILE__, __LINE__); \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_T1(X)						    \
    do {							    \
	if (debug & DBG_T1) {					    \
	    fprintf(stderr, "%s:%d: T1: ", __FILE__, __LINE__);	    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_T1_VERBOSE(X)					    \
    do {							    \
	if (debug & DBG_T1_VERBOSE) {				    \
	    fprintf(stderr, "%s:%d: T1_VERBOSE: ", __FILE__, __LINE__);	    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_GUI(X)						    \
    do {							    \
	if (debug & DBG_GUI) {					    \
	    fprintf(stderr, "%s:%d: GUI: ", __FILE__, __LINE__);    \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#define TRACE_EVENTS(X)						    \
    do {							    \
	if (debug & DBG_EVENT) {				    \
	    fprintf(stderr, "%s:%d: EVENT: ", __FILE__, __LINE__);  \
	    fprintf X;						    \
	    fprintf(stderr, "\n");				    \
	}							    \
    } while(0)
#endif /* SPEED_IS_EVERYTHING */

#endif /* XDVI_DEBUG_H */
